<?php
namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00024000ModeloDocumentoFactory {

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
 
    public function getInformacoesModeloDocumento() {
        $sql = "SELECT NRSEQMODDOCFCT,
                    DSMODELODOCORCA,
                    IDATIVO,
                    IDDOCRENEGOCIACAO,
                    VRTAMANHOLOGO,
                    DSCAMINHOARQ,
                    NMARQUIVO,
                    DSTIPO,
                    VRTAMANHO,
                    NRORG
                FROM FCT_MODELODOC
                ORDER BY NRSEQMODDOCFCT DESC";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);  
    }

    public function inserirModeloDocumento($parametros) {
        $sql = "INSERT INTO FCT_MODELODOC (NRSEQMODDOCFCT, DSMODELODOCORCA, IDATIVO, IDDOCRENEGOCIACAO, VRTAMANHOLOGO, DSCAMINHOARQ, NMARQUIVO, DSTIPO, VRTAMANHO, NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, DTINCLUSAO)
        VALUES (:NRSEQMODDOCFCT, :DSMODELODOCORCA, :IDATIVO, :IDDOCRENEGOCIACAO, :VRTAMANHOLOGO, :DSCAMINHOARQ, :NMARQUIVO, :DSTIPO, :VRTAMANHO, :NRORG, :NRORGINCLUSAO, :CDOPERINCLUSAO, SYSDATE)";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function atualizarModeloDocumento($parametros) {
        $sql = "UPDATE FCT_MODELODOC
                    SET DSMODELODOCORCA = :DSMODELODOCORCA,
                        IDATIVO = :IDATIVO,
                        IDDOCRENEGOCIACAO = :IDDOCRENEGOCIACAO,
                        VRTAMANHOLOGO = :VRTAMANHOLOGO,
                        DSCAMINHOARQ = :DSCAMINHOARQ,
                        NMARQUIVO = :NMARQUIVO,
                        DSTIPO = :DSTIPO,
                        VRTAMANHO = :VRTAMANHO,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE
                    WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function deletarModeloDocumento($parametro) {
        $sql = "DELETE FROM FCT_MODELODOC
                    WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
    }

    public function limparAnexoModeloDocumento(array $params) {
        $sql = "UPDATE FCT_MODELODOC
                   SET DSCAMINHOARQ = NULL,
                       NMARQUIVO    = NULL,
                       VRTAMANHO    = NULL,
                       DSTIPO       = NULL
                 WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getDocumento(array $params, $connection) {
        if($connection) {
            $this->connection = $connection;
        }
        $sql = "SELECT NMARQUIVO,
                  VRTAMANHO,
                  DSCAMINHOARQ,
                  DSTIPO
                FROM FCT_MODELODOC
                WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
}


?>