<?php

namespace SM\Service;

use SM\Factory\Sm00024000ModeloDocumentoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\FileServerService;
use SM\Util\Utilities;
use Zeedhi\Framework\DependencyInjection\InstanceManager;

class Sm00024000ModeloDocumentoService {

    protected $ModeloDocumentoFactory;
    protected $Environment;
    protected $newCode;
    protected $fileServerService;
    protected $fileServerUrl;

    public function __construct (EntityManager $entityManager, Sm00024000ModeloDocumentoFactory $ModeloDocumentoFactory, Environment $Environment, NewCode $newCode, FileServerService $fileServerService, $fileServerUrl) {
        $this->ModeloDocumentoFactory = $ModeloDocumentoFactory;
        $this->connection             = $entityManager->getConnection();
        $this->Environment            = $Environment;
        $this->newCode                = $newCode;
        $this->fileServerService      = $fileServerService;
        $this->fileServerUrl          = $fileServerUrl;
    }
 
    public function getInformacoesModeloDocumento() {
        return $this->ModeloDocumentoFactory->getInformacoesModeloDocumento();
    }

    public function inserirModeloDocumento($parametros) {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrorg();
            $cdoperador = $this->Environment->getCdOperador();

            if(count ($parametros['ARQUIVO']) > 0) {
                $dados = $this->fileServerService->uploadFiles($parametros['ARQUIVO'], 'anexo_modelo_documento');
                $dados[0]["size"] = $dados[0]["size"]/1024;
            } else {
                $dados = [[
                    "path" => $parametros["DSCAMINHOARQ"],
                    "size" => $parametros["VRTAMANHO"],
                    "name" => $parametros["NMARQUIVO"],
                    "type" => $parametros["DSTIPO"],
                ]];
            }
            
            if ($parametros['NRSEQMODDOCFCT'] == null) {
                $nrseqmoddocfct = $this->newCode->getCodeByTableName("FCT_MODELODOC", $nrorg, 1, 10, true);

                $params = array(
                    "NRSEQMODDOCFCT" => $nrseqmoddocfct,
                    "DSMODELODOCORCA" => $parametros['DSMODELODOCORCA'],
                    "IDATIVO" => $parametros['IDATIVO'],
                    "IDDOCRENEGOCIACAO" => $parametros['IDDOCRENEGOCIACAO'],
                    "VRTAMANHOLOGO" => $parametros['VRTAMANHOLOGO'],
                    "DSCAMINHOARQ" => $dados[0]['path'],
                    "NMARQUIVO" => $dados[0]['name'],
                    "DSTIPO" => $dados[0]['type'],
                    "VRTAMANHO" => $dados[0]['size'],
                    "NRORG"          => $nrorg,
                    "NRORGINCLUSAO"  => $nrorg,
                    "CDOPERINCLUSAO" => $cdoperador,
                );

                $this->ModeloDocumentoFactory->inserirModeloDocumento($params);
            } else {
                    $params = array(
                        "NRSEQMODDOCFCT" => $parametros['NRSEQMODDOCFCT'],
                        "DSMODELODOCORCA" => $parametros['DSMODELODOCORCA'],
                        "IDATIVO" => $parametros['IDATIVO'],
                        "IDDOCRENEGOCIACAO" => $parametros['IDDOCRENEGOCIACAO'],
                        "VRTAMANHOLOGO" => $parametros['VRTAMANHOLOGO'],
                        "DSCAMINHOARQ" => $dados[0]["path"],
                        "NMARQUIVO" => $dados[0]["name"],
                        "DSTIPO" => $dados[0]["type"],
                        "VRTAMANHO" => $dados[0]["size"],
                        "NRORGULTATU" => $nrorg,
                        "CDOPERULTATU" => $cdoperador
                    );
                    $this->ModeloDocumentoFactory->atualizarModeloDocumento($params);
            }
            $this->connection->commit();

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deletarModeloDocumento($parametros) {
        $this->connection->beginTransaction();

        try {
            foreach($parametros['NRS'] as $nr) {

                $param = array(
                    "NRSEQMODDOCFCT" => $nr
                );

                $this->ModeloDocumentoFactory->deletarModeloDocumento($param);
            }
        
            $this->connection->commit();
        }  catch(\Exception $e) {
          $this->connection->rollback();
          throw new \Exception('Operação bloqueada!<br><br> Não foi possível realizar a exclusão do documento pois o mesmo possui um registro filho.<br><br><b>ERRO:</b> '.$e->getMessage());
        }
    }

    public function limparAnexoModeloDocumento($parametros) {
            $row = $parametros["row"];

            $param = array(
                "NRSEQMODDOCFCT" => $row['NRSEQMODDOCFCT']
            );

            $this->fileServerService->deleteFile($row['DSCAMINHOARQ']);
            $this->ModeloDocumentoFactory->limparAnexoModeloDocumento($param);
    }

    public function downloadAnexoModeloDocumento($nrorg, $nrseqmoddocfct) {
        $entityManager = InstanceManager::getInstance()->getService('connectionCustom')->updateVpdConnection($nrorg);
        if (!$entityManager) {
            $entityManager = InstanceManager::getInstance()->getService('entityManager');
        }

        $param = array(
            "NRSEQMODDOCFCT" => $nrseqmoddocfct
        );
        $dados = $this->ModeloDocumentoFactory->getDocumento($param, $entityManager->getConnection());

        $url = $this->fileServerUrl."/files/".$dados[0]['DSCAMINHOARQ'];
        $nomeArquivo = $dados[0]['NMARQUIVO'];
        $tipo = $dados[0]['DSTIPO'];
        $tamanho = $dados[0]['VRTAMANHO']*1024;

        $file = @file_get_contents($url);
        if ($file) {
            Utilities::downloadArquivoFileServer($url, $nomeArquivo, $tipo, $tamanho);
        }
        else {
            echo "Arquivo não encontrado.";
            exit;
        }

        
    }
}

?>