import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Metadata, Http } from '@zeedhi/core';
import {
    LoadingService, TextInput, IGridEvent, DialogService,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class Sm00029001TipoLocalAtendimentoController {
    public adicionarTipoLocalAtendimento() {
        const grid = Metadata.getInstance<TekGrid>('tipo-local-atendimento-tek-grid');
        // const newId = (grid.datasource.total + 1).toString();
        const newId = 0;

        grid.addNewRow({ NRTIPOESTRUTURA: newId }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NMTIPOESTRUTURA_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public async salvarTipoLocalAtendimento({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('tipo-local-atendimento-tek-grid');
        const classifications = grid.getEditedRows();
        LoadingService.show();
        try {
            await Http.post('/salvarTipoLocalAtendimento', classifications);
            await grid.cancelEditedRows();
            await grid.reload();
            Utilities.showSuccessMessage();
        } catch (e) {
            Utilities.showErrorMessage(e);
        }
        LoadingService.hide();
    }

    public dialogDeletarTipoLocalAtendimento({ event }: any) {
        event.preventDefault();
        DialogService.show({
            name: 'dialog-deletar',
            type: 'warning',
            title: 'Atenção',
            text: 'Todos os dados deste(s) tipo(s) de local de atendimento serão perdidos. Deseja continuar?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'sim',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarTipoLocalAtendimento();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public async deletarTipoLocalAtendimento() {
        const grid = Metadata.getInstance<TekGrid>('tipo-local-atendimento-tek-grid');
        LoadingService.show();
        try {
            await Http.post('/deletarTipoLocalAtendimento', grid.selectedRows);
            await grid.cancelEditedRows();
            await grid.reload();
            Utilities.showSuccessMessage();
        } catch (e) {
            Utilities.showErrorMessage(e);
        }
        LoadingService.hide();
    }
}
