import {
    Http, IDictionary, Metadata,
} from '@zeedhi/core';
import {
    LoadingService, IGridEvent, DialogService,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00034001DescontoPeriodoCarenciaOperadorController {
    public labelBotaoControleCarencia = '';

    public idControleCarencia = true;

    getClassName() {
        return this.constructor.name;
    }
    
    public valorBotao() {
        LoadingService.show();
        Http.get('/getIdBloq').then((response: IDictionary) => {
            this.idControleCarencia = response.data.data[0].IDBLOQCARENCMAXI === 'S';
            this.atualizarLabelBotaoControleCarencia();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public atualizarLabelBotaoControleCarencia() {
        this.labelBotaoControleCarencia = this.idControleCarencia ? 'Desativar Controle de Carência' : 'Ativar Controle de Carência';
    }

    public adicionarDescontoPeriodoCarenciaOperador() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-operador');
        const newId = 0;
        grid.addNewRow({ NRCARENCIAOPER: newId }, 'start');
    }

    public inserirDescontoPeriodoCarenciaOperador({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-operador');
        const operadores = grid.getEditedRows();

        if (Utilities.validateGrid(grid)) {
            LoadingService.show(); Http.post('/inserirDescontoPeriodoCarenciaOperador', operadores).then(() => {
                grid.cancelEditedRows();
                Utilities.showSuccessMessage();
                grid.datasource.get();
            }).catch((error) => {
                if (error.response.data.error === 'EXISTE') {
                    Utilities.showDialogMessage('error', 'Operação Bloqueada!', 'Já existe um cadastro para o Operador informado.');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            Utilities.alertMessage('Preencha todos os campos obrigatórios', 'error');
        }
    }

    public dialogDeletarDescontoPeriodoCarenciaOperador({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, `${this.getClassName()}.deletarDescontoPeriodoCarenciaOperador`);
    }

    public deletarDescontoPeriodoCarenciaOperador() {
        DialogService.hide();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-operador');
        LoadingService.show(); Http.post('/deletarDescontoPeriodoCarenciaOperador', grid.selectedRows).then(() => {
            grid.selectedRows = [];
            grid.cancelEditedRows();
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public botaoAtivar() {
        const id = this.idControleCarencia ? 'N' : 'S';
        LoadingService.show();
        Http.post('/botaoAtivar', {
            IDBLOQCARENCMAXI: id,
        }).then(() => {
            Utilities.showSuccessMessage();
            this.idControleCarencia = !this.idControleCarencia;
            this.atualizarLabelBotaoControleCarencia();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
