import {
    Http, Metadata,
} from '@zeedhi/core';
import {
    LoadingService, IGridEvent, DialogService,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00034002DescontoPeriodoCarenciaPerfilAcessoController {
    public adicionarDescontoPeriodoCarenciaPerfilAcesso() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-perfil-acesso');
        const newId = 0;
        grid.addNewRow({ NRCARENCIAPERFIL: newId }, 'start');
    }

    getClassName() {
        return this.constructor.name;
    }

    public inserirDescontoPeriodoCarenciaPerfilAcesso({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-perfil-acesso');
        const perfis = grid.getEditedRows();

        if (Utilities.validateGrid(grid)) {
            LoadingService.show(); Http.post('/inserirDescontoPeriodoCarenciaPerfilAcesso', perfis).then(() => {
                grid.cancelEditedRows();
                Utilities.showSuccessMessage();
                grid.datasource.get();
            }).catch((error) => {
                if (error.response.data.error === 'EXISTE') {
                    Utilities.showDialogMessage('error', 'Operação Bloqueada!', 'Já existe um cadastro para o Perfil de Acesso informado.');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            Utilities.alertMessage('Preencha todos os campos obrigatórios', 'error');
        }
    }

    public dialogDeletarDescontoPeriodoCarenciaPerfilAcesso({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, `${this.getClassName()}.deletarDescontoPeriodoCarenciaPerfilAcesso`);
    }

    public deletarDescontoPeriodoCarenciaPerfilAcesso() {
        DialogService.hide();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-perfil-acesso');
        LoadingService.show(); Http.post('/deletarDescontoPeriodoCarenciaPerfilAcesso', grid.selectedRows).then(() => {
            grid.selectedRows = [];
            grid.cancelEditedRows();
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
