/* eslint-disable */
import {
    Http, Metadata, Config, IEventParam
} from '@zeedhi/core';
import {
    DialogService, Form, LoadingService, Modal, ModalService, Select, TextInput, Number, Text, FileInput, Row, Button
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class sm_00024_000_modelo_documentos_controller {   
    private basicModal!: Modal;

    public habilitarBotao = true;

    public async exibirModal() {
        this.basicModal = await ModalService.createFromJson('sm_00024_000_modelo_documentos/modal/sm_00024_000_insercao_documento', true);
        this.basicModal.show();
    }

    public fecharModal() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async abrirModalInsercao() {
        await this.exibirModal();
        Metadata.getInstance<Text>('titleText').text = "Inserção de Modelo de Documento";
    }

    public async abrirModalEdicao({row} : any) {
        await this.exibirModal();
        Metadata.getInstance<Text>('titleText').text = "Edição de Modelo de Documento";
        Metadata.getInstance<TextInput>('NRSEQMODDOCFCT').value = row.NRSEQMODDOCFCT;
        Metadata.getInstance<Select>('IDATIVO').value = row.IDATIVO;
        Metadata.getInstance<TextInput>('DSMODELODOCORCA').value = row.DSMODELODOCORCA;
        Metadata.getInstance<Select>('IDDOCRENEGOCIACAO').value = row.IDDOCRENEGOCIACAO;
        Metadata.getInstance<Number>('VRTAMANHOLOGO').value = row.VRTAMANHOLOGO;
        Metadata.getInstance<TextInput>('DSCAMINHOARQ').value = row.DSCAMINHOARQ;
        Metadata.getInstance<Number>('VRTAMANHO').value = row.VRTAMANHO;
        Metadata.getInstance<TextInput>('NMARQUIVO').value = row.NMARQUIVO;
        Metadata.getInstance<TextInput>('DSTIPO').value = row.DSTIPO;
        
        if(Metadata.getInstance<TextInput>('NMARQUIVO').value != null) {
            Metadata.getInstance<FileInput>('ARQUIVO').isVisible = false;
        } else {
            Metadata.getInstance<FileInput>('ARQUIVO').isVisible = true;
        }
    }

    public async inserirModeloDocumento() {
        const form = Metadata.getInstance<Form>('form').validate();
        const grid = Metadata.getInstance<TekGrid>('tek-grid-modelo-documento');

        if (form) {
            const file = await Utilities.buildArrayToUpload('ARQUIVO');
            LoadingService.show();
            Http.post('/inserirModeloDocumento', {
                NRSEQMODDOCFCT: Metadata.getInstance<TextInput>('NRSEQMODDOCFCT').value,
                DSMODELODOCORCA: Metadata.getInstance<TextInput>('DSMODELODOCORCA').value,
                IDATIVO: Metadata.getInstance<Select>('IDATIVO').value,
                IDDOCRENEGOCIACAO: Metadata.getInstance<Select>('IDDOCRENEGOCIACAO').value,
                VRTAMANHOLOGO: Metadata.getInstance<Number>('VRTAMANHOLOGO').value,
                DSCAMINHOARQ: Metadata.getInstance<TextInput>('DSCAMINHOARQ').value,
                NMARQUIVO: Metadata.getInstance<TextInput>('NMARQUIVO').value,
                DSTIPO: Metadata.getInstance<TextInput>('DSTIPO').value,
                VRTAMANHO: Metadata.getInstance<Number>('VRTAMANHO').value,
                ARQUIVO: file,
            }).then(() => {
                this.fecharModal();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            console.log('Preencha todos os campos obrigatórios (*)', 'error');
        }
    }

    public dialogDeletarModeloDocumento({component, event}: any) {
        event.preventDefault();

        DialogService.show({
            name: 'dialog-deletar-modelo-doc',
            type: 'warning',
            title: 'Atenção',
            text: "Todos os dados deste(s) modelo(s) de documento(s) serão perdidos. Deseja continuar?",
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarModeloDocumento(component);
                            DialogService.hide();
                        }
                    },
                },
            ],
        });
    }

    public deletarModeloDocumento(component : any) {
        const NRS = (component.selectedRows.map((element: any) => element.NRSEQMODDOCFCT));

        LoadingService.show();
        Http.post('/deletarModeloDocumento', {
            NRS: NRS,
        }).then(() => {
            component.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public dialogDeletarAnexoModeloDocumento({row}: IEventParam<Button>) {
        DialogService.show({
            name: 'dialog-deletar-anexo',
            type: 'warning',
            title: 'Atenção',
            text: "O(s) anexo(s) deste(s) modelo(s) de documento(s) serão perdidos. Deseja continuar?",
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarAnexoModeloDocumento(row);
                            DialogService.hide();
                        }
                    },
                },
            ],
        });
    }

    public habilitarBotaoGrid({row}: any) {
        return (row.NMARQUIVO != null);
    }

    public cliqueCelula({column, event, component}: any) {
        let preventRowClick = false;
        if (column.name === 'DELETARANEXO' || column.name === 'DOWNLOADANEXO') {
            preventRowClick = true;
        }
        return preventRowClick;
    }

    public deletarAnexoModeloDocumento(row: Row) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-modelo-documento');

        LoadingService.show();
        Http.post('/deletarAnexoModeloDocumento', {
            row: row
        }).then(() => {
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public downloadAnexoModeloDocumento({row}: any) {
        const nrseqmoddocfct = row['NRSEQMODDOCFCT'];
        const nrorg = row['NRORG'];
        window.open(Config.endPoint+'downloadAnexoModeloDocumento?nrorg='+nrorg+'&nrseqmoddocfct='+nrseqmoddocfct);

    }
}