import store from '@/store';
import Vue from 'vue';
import { Component } from 'vue-property-decorator';
import { Config } from '@zeedhi/core';
import { TekLibLocalStorage } from '@zeedhi/tek-lib';

/**
 * Microservice
 */
@Component
export default class Mircroservice extends Vue {
    private page: string = '';

    public microservicePath() {
        const { module, page } = store.getters.routerParams;
        this.setProductInfoLocalStorage();

        if (process.env.NODE_ENV === 'production') {
            return `${window.location.origin}/${module}`;
        }

        const userAuth = JSON.stringify({
            LOGIN_TOKEN: localStorage.getItem('LOGIN_TOKEN'),
            LOGIN_USER: localStorage.getItem('LOGIN_USER'),
            LOGIN_USER_NAME: localStorage.getItem('LOGIN_USER_NAME'),
            LOGIN_LANGUAGE: localStorage.getItem('LOGIN_LANGUAGE'),
            LOGIN_HASH: localStorage.getItem('LOGIN_HASH'),
            LOGIN_KEEP_CONNECTED: localStorage.getItem('LOGIN_KEEP_CONNECTED'),
        });

        const productInfo = JSON.stringify({
            PRODUCT_ID: TekLibLocalStorage.getItem('IS_NEXT') ? Config.env.product.id : TekLibLocalStorage.getItem('PRODUCT_ID'),
            PRODUCT_URL: Config.env.product.url,
            PRODUCT_LOGO_URL: Config.env.product.logoUrl,
            PRODUCT_BACKGROUND_IMG_PATH: Config.env.loginBackgroundImgUrl,
            MODULES_THEME_COLOR: Config.env.product.modulesThemeColor.replace('#', ''),
        });

        if (!this.page) {
            this.page = page;
        }
        return `${Config.env.modules[module].baseUrl}?page=${page}&user_auth=${userAuth}&product_info=${productInfo}`;
    }

    private setProductInfoLocalStorage() {
        if (TekLibLocalStorage.getItem('IS_NEXT')) {
            localStorage.setItem('PRODUCT_ID', Config.env.product.id);
        }
        localStorage.setItem('PRODUCT_URL', Config.env.product.url);
        localStorage.setItem('PRODUCT_LOGO_URL', Config.env.product.logoUrl);
        localStorage.setItem('PRODUCT_BACKGROUND_IMG_PATH', Config.env.loginBackgroundImgUrl);
        localStorage.setItem('MODULES_THEME_COLOR', Config.env.product.modulesThemeColor);
    }
}
